'use strict';

var got = require('got');
var moment = require('moment-timezone');
var isString = require('lodash/isString');
var isObject = require('lodash/isObject');
var isBoolean = require('lodash/isBoolean');
var groupBy = require('lodash/groupBy');
var sortBy = require('lodash/sortBy');
var toArray = require('lodash/toArray');
var isDate = require('lodash/isDate');
var merge = require('lodash/merge');

var createStopover = function createStopover(s) {
    var arrival = null;
    if (s.h_arv_tm !== '999999') {
        arrival = moment.tz(s.h_arv_dt + '_' + s.h_arv_tm, 'YYYYMMDD_HHmmss', 'Asia/Seoul').format();
    }
    var departure = null;
    if (s.h_dpt_tm !== '999999') {
        departure = moment.tz(s.h_dpt_dt + '_' + s.h_dpt_tm, 'YYYYMMDD_HHmmss', 'Asia/Seoul').format();
    }

    return {
        station: {
            type: 'station',
            id: s.h_stop_rs_stn_cd + '',
            name: s.h_stop_rs_stn_nm
        },
        arrival: arrival,
        departure: departure
        // todo: h_act_arv_dlay_tnum
    };
};

var journeyLeg = async function journeyLeg(lineId, departureDate) {
    if (!isString(lineId) || lineId.length === 0) throw new Error('invalid or missing `lineId`, must be string');

    if (!isDate(departureDate)) throw new Error('`departureDate` must be a JS Date() object');
    // const day = moment.tz(departureDate, 'Asia/Seoul').format('YYYYMMDD')
    var day = '20180620';

    var results = await got.post('https://smart.letskorail.com/classes/com.korail.mobile.trainsInfo.TrainSchedule', {
        query: {
            Device: 'IP',
            // Sid: '1QihOasC3e4vT2ld1RRiMw==',
            // Version: '180314001',
            srtCheckYn: 'Y',
            txtRunDt: day,
            txtTrnNo: lineId
        },
        json: true
    }).then(function (res) {
        return res.body;
    });

    if (results.strResult !== 'SUCC') throw new Error(JSON.stringify(results));

    return results.time_infos.time_info.map(createStopover);
};

module.exports = journeyLeg;